.. genmechanics documentation master file, created by
   sphinx-quickstart on Fri Nov 18 22:14:09 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

genmechanics: documentation
===========================

Contents:

.. toctree::
   :maxdepth: 2

The goal of genmechanics is to provide a tool for defining and computing some general mechanics model.
In these models, mechanical models are modeled as a set of parts connected together by linkages. 

Examples
========
Some examples can be found at: https://github.com/masfaraud/genmechanics/tree/master/scripts

Developement
============
The github repo: https://github.com/masfaraud/genmechanics/

Release notes
-------------

Roadmap
-------

 * Kinematics
 * Non linear linkages: gear and bearing losses...

Reference
=========

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

